/*
 * Copyright (c) 2000 Southeastern Universities Research Association,
 *               Continuous Electron Beam Accelerator Facility
 *
 * This software was developed under a United States Government license
 * described in the NOTICE file included as part of this distribution.
 *
 *
 *  Revision History:
 *  03/10/00:  Release version 0.1.
 *  04/17/00:  Release version 0.2 (add format & direction constatnts)
 *  08/25/00:  Release version 0.3 (add axis position etc. )
 *
 */

package	adm;

/**
 * This interface contains a collection of constants generally used 
 * for adm components 
 *
 *
 * @version   0.4  09/07/00
 * @author    Ying Chen,  Chip Watson
 *           (Based on work by Cuong Quach and Mr. John Winans)
 * @since     adm0.1
 */
public interface CConstants {

    //------------ Label style option constants ----------------------
    /**
     * Label style option - no label
     */
    public static final byte LABEL_NONE = 0;

    /**
     * Label style option - with tick marks, high and low value
     */
    public static final byte LABEL_AXIS = 1;

    /**
     * Label style option - with tick mark, high/low value, 
     * current value
     */
    public static final byte LABEL_VALUE  = 2;

    /**
     * Label style option - with tick mark, high/low value, 
     * current value and device-priperty name
     */
    public static final byte LABEL_ALL = 3;


    //-------------- Range style option constants ------------------
    /**
     *  Range style option - get range from device-property
     */
    public static final byte RANGE_FROM_PROPERTY = 0;

    /**
     * Range style option - auto range
     */
    public static final byte RANGE_AUTO = 1;

    /**
     * Range style option - user set range
     */
    public static final byte RANGE_STATIC = 2;


    //--------------- Color mode option constants --------------------
    /**
     * color mode option - foreground color don't change
     */
    public static final byte CLRMOD_STATIC = 0;

    /**
     * color mode option - foreground color changed according to the state 
     */

    public static final byte CLRMOD_ALARM = 1;
    /*
     * color mode option - ??? (not implemented)
     */
    //public static final byte CLRMOD_DISCRETE = 2;

	     
    //----------------- Alignment option constants ------------------
    /**
     * alignment option - left alignment (only used in CText class)
     */
    public static final byte ALIGN_LEFT = 0;

    /**
     * alignment option - center alignment (only used in CText class)
     */
    public static final byte ALIGN_CENTER = 1;

    /**
     * alignment option - right alignment (only used in CText class)
     */
    public static final byte ALIGN_RIGHT = 2;


    //--------------- orietation option constants --------------------
    /**
     * orientation option - horizontal direction. (used in CBar,
     * CIndicator and CSlider widgets).
     */
    public static final byte HORIZONTAL = 0;

    /**
     * orientation option - vertical direction. ( used in CBar,
     * CIndicator and CSlider widgets).
     */
    public static final byte VERTICAL = 1;
     
   
    //--------------- direction option constants --------------------
    /**
     * direction option - bits position start from bottom 
     * (used in CBits widget)
     */
    public static final byte DIR_UP = 2;

    /**
     * direction option - bits position start from top 
     * (used in CBits widget)
     */
    public static final byte DIR_DOWN = 3;

    /**
     * direction option - bits position start from right 
     * (used in CBits widget)
     */
    public static final byte DIR_RIGHT = 1;

    /**
     * direction option - bits position start from left 
     * (used in CBits widget)
     */
    public static final byte DIR_LEFT = 0;


    //------------- fill option constants --------------------------
    /**
     * fill option - fill from edge (only used in CBar widget)
     */
    public static final byte FILL_FROM_EDGE = 0;

    /**
     * fill option - fill from center (only used in CBar widget)
     */
    public static final byte FILL_FROM_CENTER = 1;


    //------------- format option constants --------------------------
    /**
     * format option - display the value as a integer number 
     * (following printf %d conventions)
     */
    public static final String FRMT_INTEGER = "%d";

    /**
     * format option - display the value as float number with 3 decimal places
     * (following printf %.3f conventions)
     */
    public static final String FRMT_FLOAT = "%.3f";

    /**
     * format option - display the value as scientific notation
     * (following printf %.3e conventions)
     */
    public static final String FRMT_SCIENTIFIC = "%.3e";

    /**
     * format option - display the value as float number or scientific
     * notation,  whichever is shorter (following printf %.3g conventions)
     */
    public static final String FRMT_AUTO = "%.3g";

    /**
     * format option - display the value as unsigned hexadecimal number.
     * (following printf %#x conventions)
     */
    public static final String FRMT_HEX = "%#x";

    /**
     * format option - display the value as unsigned octal number.
     * (following printf %#o conventions)
     */
    public static final String FRMT_OCTAL = "%#o";


    //------------- stacking option constants ----------------------
    /**
     * Specify buttons to be placed side by side (used in 
     * CToggleButton widget)
     */
    public static final byte COLUMN = 0;

    /**
     * Specify buttons to be placed one above the other (used in
     * CToggleButton widget)
     */
     public static final byte ROW = 1;


    //-------------  directory service query type -----------------
    /**
     * Specify the directory service is class name query <BR>
     * (used in CDirectory class)
     */
    public static final byte CLASS_QUERY = 0;

    /**
     * Specify the directory service is device name query<BR>
     * (used in CDirectory class)
     */
    public static final byte DEVICE_QUERY = 1;

   /**
     * Specify the directory service is property name query<BR>
     * (used in CDirectory class)
     */
    public static final byte PROPERTY_QUERY = 2;


    //------------- axis position constants -----------------
    /**
     * Specify a axis drawn on the left
     */
    public static final byte AXIS_LEFT = 0;
    
    /**
     * Specify a axis drawn on the bottom
     */
    public static final byte AXIS_BOTTOM = 1;

    /**
     * Specify a axis drawn on the left
     */
    public static final byte AXIS_RIGHT = 2;
    
    /**
     * Specify a axis drawn on the top
     */
    public static final byte AXIS_TOP = 3;


    //------------- axis style constants -----------------
    /**
     * Specify a linear scale axis
     */
    public static final byte AXIS_STYLE_LINEAR = 0;
    
    /**
     * Specify log10 scale axis (not implemented yet)
     */
    public static final byte AXIS_STYLE_LOG10  = 1;   


    //------------- trace style constants -----------------
    /** 
     * Specify trace Style as scatter points (used in CCartesian widget)
     */
    public final static byte STYLE_POINT = 0;

    /** 
     * Specify trace Style as connected line (used in CCartesian widget)
     */
    public final static byte STYLE_LINE = 1;
    
    /* 
     * Specify trace Style as fill area under line (used in CCartesian widget)
     * (not implemented yet)
     */
    public final static byte STYLE_FILLUNDER = 2;


}  // end of CConstants class







