/*
 * Copyright (c) 2000 Southeastern Universities Research Association,
 *                    Continuous Electron Beam Accelerator Facility
 *
 * This software was developed under a United States Government license
 * described in the NOTICE file included as part of this distribution.
 *
 *
 *  Revision History:
 *  10/27/00:  Initial version.
 *
 */

package adm;

import java.awt.*;
import java.util.Hashtable;
import cdev.*;

/**
 * Create a named application invoked by CJavaMenuItem widget. And
 * initializes a connection to a server, typically a gateway such as 
 * cdevGateway if it is not connected.
 * <BR><BR>
 * The child class must provide a null constructor and the main method.
 * It is also necessary to overwite the setArgs(String[]) method if 
 * there is any argument needed to be passed. 
 * <BR><BR>
 * CNamedApplication is a subclass of CApplication and has a static hash 
 * table to keep track the running instance. Every time when the menu button
 * is pressed, the CNamedApplication will search the hash table to find the 
 * instance with same name (args[0]). If the instance is found, the arguments 
 * will be reset (call application's setArgs method) and then the window will 
 * be brought to the front. If not found a new instance will be started up. 
 * By passing different argument the user can control the number of instance 
 * (window). Only one instance per name (using args[0] as the name or the 
 * empty string "" if no argument) will be shown up. 
 * <BR><BR>
 *
 * @version   1.0  10/27/00
 * @author    Ying Chen, Chip Watson
 *
 * @since     adm1.0
 *
 */
public abstract class CNamedApplication extends CApplication 
{

    static Hashtable all = new Hashtable();

    /**
     * Null Constructor
     */
    public CNamedApplication ()
    {
	super();
    }
    
    
    /**
     * Constructor
     * @param host    cdevGateway host name
     * @param port    port number cdevGateway used
     */
    public CNamedApplication (String host, int port)
    {
	super(host, port);
    }

    
    /**
     * constructor
     * @param host    cdevGateway host name
     * @param port    port number cdevGateway used
     * @param title   the title of the frame
     */
    public CNamedApplication (String host, int port, String title)
    {
	super(host, port, title);
    }


    /**
     * Constructor
     * @param title   the title of the frame
     */
    public CNamedApplication (String title)
    {
	super(title);
    }


    /**
     * Set the args as the array of String
     * It is empty and must be overwrited by child class
     * if there is any args needed to passed
     */
    public void setArgs (String[] args) { }


    /**
     * This static method is used to invoke the child class "myName"
     * with arguments args.
     * It must be called by the main method of the child class.
     *   
     * @param myName   the name String of child class name
     * @param args     the argument array  
     */ 
    public static Object invoke (String myName, String[] args) {
	String key;
	if (args == null) key = "";
	else              key = args[0];
	CNamedApplication one = (CNamedApplication)all.get(key);
	if (one == null) {
	    try {
		one = (CNamedApplication)Class.forName(myName).newInstance();
		one.setArgs(args);
	    } catch (Exception e) { 
		System.out.println("Start class ("+myName+") failed"); 
	    }
	    one.show();
	    all.put(key, one);
	    }
	else {
	    one.setArgs(args);
	    if (one.isShowing()) one.toFront();
	    else {
		one.show();
		connection_count++;
	    }
	    System.out.print("CNamedApplication:: find a existing instance");
	    System.out.println(" and con count = "+connection_count);
	}
	return one;
    }
}




