/*
 * Copyright (c) 2000 Southeastern Universities Research Association,
 *                    Continuous Electron Beam Accelerator Facility
 *
 * This software was developed under a United States Government license
 * described in the NOTICE file included as part of this distribution.
 *
 *  Revision History:
 *  03/10/00:  Release version 0.1. 
 *  04/17/00:  Release version 0.2.
 *
 */

package adm;

import java.awt.*;
import cdev.*;

/**
 * COval is awt component bean. It is used to monitor the state of a
 * specific device property in a control system. The size, bound, 
 * foreground and background can be set like the awt component. 
 * <BR><BR>
 * COval has the color mode property. When it is set to CLRMOD_ALARM,
 * the color of this widget will change from foreground to yellow or red 
 * if the property is in warning or alarm state (determined by warning and 
 * alarm limits). When the foreground and the background color are the 
 * same as the container's, this widget will only appear when the device 
 * property is in the warning and alarm states. 
 * <BR><BR>
 * Since version 0.3 this widget can used to monitor the Enum type 
 * device - property. A color map (table) is used to represent the state 
 * when the color mode is CLRMOD_ALARM. Default colorMap contains 12 
 * colors, and uses color black for state above 12. User can overwrite 
 * this colorMap by calling the setColorMap (Color[] newColor). If the 
 * length of the newColor is less than the number of the Enum states, 
 * the color black will be used for the remaining states. 
 *
 *
 * @version   0.2  04/17/00
 * @author    Ying Chen, Chip Watson
 *            (Based on work by Cuong Quach and Mr. John Winans)
 * @since     adm0.1
 *
 */
public class COval extends CRect {
     
   
    /**
     *  Null Constructor.
     */
    public COval ()
    {
	super();	
    }
	
    /**
     * Constructor with device name and property name
     *
     * @param dName    device name
     * @param pName    property name
     */
    public COval(String dName, String pName)
    {
        super(dName, pName);
    }

    /**
     * Constuctor.
     * @param w   the width of the component
     * @param h   the height of the component
     */
    public COval (int w, int h) 
    {
	super(w, h);	
    }


    /**
     * Constuctor.
     * @param w   the width of the component
     * @param h   the height of the component
     * @param fg  the foreground color of the component
     * @param bg  the background color of the component
     */ 
    public COval (int w, int h, Color fg, Color bg) 
    {
	super(w, h, fg, bg);	
    }
		
    /**
     * Paint the Oval with new foreground color
     */ 
    public void paint (Graphics g) 
    {
	Dimension rec = getSize(); 
	g.setColor(getParent().getBackground());
	g.fillRect(0, 0, rec.width, rec.height);
	g.setColor(currColor);
	g.fillOval(0, 0, rec.width, rec.height);
    }
     
} //end of COval






