/*
 * Copyright (c) 2000 Southeastern Universities Research Association,
 *                    Continuous Electron Beam Accelerator Facility
 *
 * This software was developed under a United States Government license
 * described in the NOTICE file included as part of this distribution.
 *
 *
 *  Revision History:
 *  10/27/00:  Initial version.
 *
 */

package adm;

import java.awt.*;
import java.awt.event.*;
import java.util.Hashtable;
import cdev.*;

/**
 * Create a singleton application invoked by CJavaMenuItem widget.
 * Initializes a connection to a server, typically a gateway such as 
 * cdevGateway if it is not connected.
 * <BR><BR>
 * The child class must provide a null constructor and the main method.
 * It is also necessary to verwite the setArgs(String[]) method if 
 * there is any argument needed to be passed. 
 * <BR><BR>
 * CsingletonApplication is a subclass of CApplication and has a static 
 * class pointer defined to keep tracking the instance. Only one instance 
 * will be invoked in same virtue machine if the application extends the 
 * CSingleApplication. When more instances are needed it is better to 
 * using the CNamedApplication as the parent class.
 * <BR><BR>
 *
 *
 * @version   1.0  10/27/00
 * @author    Ying Chen, Chip Watson
 *
 * @since     adm1.0
 *
 */
public abstract class CSingletonApplication extends CApplication 
{

    static CSingletonApplication one = null;

    /**
     * Null Constructor
     */
    public CSingletonApplication ()
    {
	super();
    }
    

    /**
     * Constructor
     * @param title   the title of the frame
     */
    public CSingletonApplication (String title)
    {
	super(title);
    }

    
    /**
     * Constructor
     * @param host    cdevGateway host name
     * @param port    port number cdevGateway used
     */
    public CSingletonApplication (String host, int port)
    {
	super(host, port);
    }


    /**
     * constructor
     * @param host    cdevGateway host name
     * @param port    port number cdevGateway used
     * @param title   the title of the frame
     */

    public CSingletonApplication (String host, int port, String title)
    {
	super(host, port, title);
    }

    
   /**
     * Set the args as the array of String
     * It is empty and must be overwrited by child class
     * if there is any args needed to passed
     */
    public void setArgs( String[] args) { }
    

    /**
     * This static method is used to invoke the child class "myName"
     * with arguments "args".
     * It must be called by the main method of the child class.
     *
     * @param myName   the name String of child class name
     * @param args     the argument array 
     */ 
    public static Object invoke (String myName, String[] args) {
	if (one == null) {
	    try {
		one = (CSingletonApplication)Class.forName(myName).newInstance();
		one.setArgs(args);
	    } catch (Exception e) { 
		System.out.println("Start class ("+myName+") failed"); 
	    }
	    one.show();
	}
	else {
	    one.setArgs(args);
	    if (one.isShowing()) one.toFront();
	    else {
		one.show();
		connection_count++;
	    }
	    System.out.print("CSingletonApplication:: find existing instance");
	    System.out.println(" and connection count = "+connection_count);
	}
	return one;
    }


}




