/*
 * Copyright (c) 2000 Southeastern Universities Research Association,
 *                    Continuous Electron Beam Accelerator Facility
 *
 * This software was developed under a United States Government license
 * described in the NOTICE file included as part of this distribution.
 *
 *  Revision History:
 *  06/22/00:  Release version 0.3.
 *
 */

package adm;

import java.beans.*;

/**
 * BeanInfo for CStripChart
 *
 * @version   0.3  06/22/00
 * @author    Ying Chen, Chip Watson
 * @since     adm0.3
 *
 */
public class CStripChartBeanInfo extends SimpleBeanInfo {
    
    private final static Class BEAN_CLASS = CStripChart.class;

    public BeanInfo[] getAdditionalBeanInfo() {
	try {
	    java.util.Vector v = new java.util.Vector();
	    BeanInfo[] rv;
	    BeanInfo b;
	    Class c = BEAN_CLASS.getSuperclass();
	    
	    while (c.isAssignableFrom(Object.class) != true) {
		b = Introspector.getBeanInfo(c);
		v.addElement(b);
		c = c.getSuperclass();
	    }
	    rv = new BeanInfo[v.size()];
	    v.copyInto(rv);
	    
	    return rv;
	}
	catch (IntrospectionException e) { throw new Error(e.toString());}
    }
    
    public BeanDescriptor getBeanDescriptor() {
	BeanDescriptor bd = new BeanDescriptor(BEAN_CLASS);
	return (BeanDescriptor) bd;
    }

    public java.awt.Image getIcon(int iconKind) {
	java.awt.Image img;
	if (iconKind == BeanInfo.ICON_MONO_16x16 ||
	    iconKind == BeanInfo.ICON_COLOR_16x16) {
	    img = loadImage("CStripChartC16.gif");
	}	
	else if (iconKind == BeanInfo.ICON_MONO_32x32 ||
	    iconKind == BeanInfo.ICON_COLOR_32x32) {
	    img = loadImage("CStripChartC32.gif");
	}
	else { img = null; }
	return img;
	}

    public PropertyDescriptor[] getPropertyDescriptors() {
	try{
	    PropertyDescriptor high = 
		new PropertyDescriptor("displayHi", BEAN_CLASS);
	    high.setBound(true);
	    high.setConstrained(false);
	    high.setDisplayName("display high");
	    
	    PropertyDescriptor low = 
		new PropertyDescriptor("displayLo", BEAN_CLASS);
	    low.setBound(true);
	    low.setConstrained(false);
	    low.setDisplayName("display low");
	             
	    PropertyDescriptor range = 
                new PropertyDescriptor("rangeStyle", BEAN_CLASS);
            range.setBound(true);
            range.setConstrained(false);
            range.setDisplayName("range style");
            range.setValue("ENUMERATION", "RANGE_FROM_PROPERTY=0, RANGE_AUTO=1, RANGE_STATIC=2");
 
	    PropertyDescriptor label = 
		new PropertyDescriptor("labelStyle", BEAN_CLASS);
	    label.setBound(true);
	    label.setConstrained(false);
	    label.setDisplayName("label style");
	    label.setValue("ENUMERATION", "LABEL_NONE=0, LABEL_AXIS=1, LABEL_VALUE=2, LABEL_ALL=3");
	    
	    PropertyDescriptor period = 
		new PropertyDescriptor("displayPeriod", BEAN_CLASS);
	    period.setBound(true);
	    period.setConstrained(false);
	    period.setDisplayName("display period");

	    PropertyDescriptor axis = 
		new PropertyDescriptor("commonAxis", BEAN_CLASS);
	    axis.setBound(true);
	    axis.setConstrained(false);
	    axis.setDisplayName("common axis");
	    
	    PropertyDescriptor[] rv = {high, low, range, label, period, axis};
	    return rv;
	} catch (IntrospectionException e) { throw new Error(e.toString()); }
    }
    
    public int getDefaultPropertyIndex() {
	return 0;	//  the index for our default property is always 0
    }
    
}  // end of class CStripChartInfo



