package cdev.dir;

import java.io.*;
import java.util.*;
import java.sql.*;

/**
 * For device class data and references to DeviceProperty objects.
 * <P>
 * <P>You can obtain lists of property names
 * defined for the device class with
 * <a href="#getPropertyNames()">
 *    getPropertyNames()</a> and
 * <a href="#getPropertyNames(java.lang.String)">
 *    getPropertyNames(listName)</a>.
 * You can obtain the DeviceProperty object itself with
 * <a href="#getDeviceProperty(java.lang.String)">
 * getDeviceProperty(propertyName)</a>
 * <P>
 * A DeviceClass object is identified by its name which must be
 * unique for the implementation.
 * <BR>An array of all deviceclass names can be obtained with
 * <a href="cdev.dir.DirectoryService.html#getDeviceClassNames()">
 * DirectoryService#getDeviceClassNames()</a>.
 * <BR>A subset array of deviceclass names can be obtained with
 * <a href="cdev.dir.DirectoryService.html#getDeviceClassNames(java.lang.String)">
 * DirectoryService#getDeviceClassNames(query)</a>.
 * <P>
 * A DeviceClass object can be obtained with
 * <a href="cdev.dir.DirectoryService.html#getDeviceClass(java.lang.String)">
 * DirectoryService#getDeviceClass(className)</a>.
 * <P>
 * General documentation in <a href="DirectoryService.html">DirectoryService</a> .
 *
 * @author   J.Cuperus
 * @version  1.0
 *
 * @see DeviceData
 * @see DeviceProperty
 * @see DeviceList
 */
public interface DeviceClass extends DirectoryItem {

//---------------------------------------------------------------------------

/**
 * Gets DeviceProperty object, given the property name.
 *
 * @param propertyName the name of the property
 * @return DeviceProperty object
 * @exception NoSuchDataException    -
 * @exception BadConnectionException -
 * @exception TooManyValuesException -
 */
public DeviceProperty getDeviceProperty(String propertyName)
       throws NoSuchDataException, BadConnectionException, TooManyValuesException;

//---------------------------------------------------------------------------

/**
 * Gets array of all propertylist names for the deviceclass.
 * Array is ordered by list name.
 *
 * @return array of propertylist names
 * @exception NoSuchDataException    -
 * @exception BadConnectionException -
 */
public String[] getPropertyListNames()
       throws NoSuchDataException, BadConnectionException;

//---------------------------------------------------------------------------

/**
 * Gets array of all property names for the deviceclass.
 * Array is ordered by property name.
 *
 * @return array of property names
 * @exception NoSuchDataException    -
 * @exception BadConnectionException -
 */
public String[] getPropertyNames()
       throws NoSuchDataException, BadConnectionException;

//---------------------------------------------------------------------------

/**
 * Gets a ordered subset of the property names of a class.
 *
 * @param listName the name for the sublist of properties for the device class.
 * @return array of property names
 * @exception NoSuchDataException    -
 * @exception BadConnectionException -
 */
public String[] getPropertyNames(String listName)
       throws NoSuchDataException, BadConnectionException;

//---------------------------------------------------------------------------

}
